@@ -85,6 +85,8 @@ BASE = 'VirtualHostBase/http/%s:80/%s/VirtualHostRoot'
 URL = 'http://%s:%s@%s:%s/%s/%s'
 DIRECT_URL = 'http://%s:%s@%s:%s/%s'
 STOP_SEARCH = 'Zope Ready to handle requests'
+FALSE_VALUE = ('no', 'False', 'false', '0')
+
 wmi = dict()
 gsm = component.getGlobalSiteManager()
 
@@ -218,6 +220,7 @@ class myURLOpener(urllib.FancyURLopener):
     # read an URL, with automatic HTTP authentication
 
     follow_redirection = True ## by default follow_redirection
+    use_proxies = True ## by default use environ for proxy
 
     def http_error_302(self, url, fp, errcode, errmsg, headers, data=None):
         """Error 302 -- relocated (temporarily)."""
@@ -232,6 +235,11 @@ class myURLOpener(urllib.FancyURLopener):
     def http_error_default(self, url, fp, errcode,errmsg, headers):
         errcode = str(errcode)
         if errcode.startswith('4') or errcode.startswith('5'):
+            try:
+                logger.debug(headers)
+                logger.debug(fp.read())
+            except:
+                pass
             raise HTTPException(url, errcode, errmsg)
 
     def setpasswd(self, user, passwd):
@@ -257,6 +265,9 @@ class myURLOpener(urllib.FancyURLopener):
 
     def open( self, fullurl, data=None, timeout = None):
         t = time.time()
+        if self.use_proxies is False:
+             ### erase all config about that
+             self.proxies = dict()
         r = urllib.FancyURLopener.open(self, fullurl, data)
         self.elapse = time.time() - t
 
@@ -1321,10 +1332,12 @@ def main():
     ZeoClient.perf_file = getPerfFile(config.get('DEFAULT','perfdir'))
     if config.has_option('DEFAULT','follow_redirection'):
         ## in some case we dont want follow redirection
-        if  config.get('DEFAULT','follow_redirection') in ('no','False',
-                                                           'false', '0'):
+        if  config.get('DEFAULT','follow_redirection') in FALSE_VALUE:
              myURLOpener.follow_redirection = False
-
+    if config.has_option('connect','use_http_proxy') and\
+            config.get('connect','use_http_proxy') in FALSE_VALUE:
+        myURLOpener.use_proxies = False
+    
     cluster = Cluster(config)
     
     lock_path = os.path.join(os.getcwd(),config.get('DEFAULT',
